@@ -220,7 +220,9 @@ public abstract class ClassLoader {
 				System.setSecurityManager(new SecurityManager());
 			} else {
 				try {
-					System.setSecurityManager((SecurityManager)Class.forName(javaSecurityManager, true, applicationClassLoader).getDeclaredConstructor().newInstance());
+					Constructor<?> constructor = Class.forName(javaSecurityManager, true, applicationClassLoader).getConstructor();
+					constructor.setAccessible(true);
+					System.setSecurityManager((SecurityManager)constructor.newInstance());
 				} catch (Throwable e) {
 					// K0631 = JVM can't set custom SecurityManager due to {0}
 					throw new Error(com.ibm.oti.util.Msg.getString("K0631", e.toString()), e); //$NON-NLS-1$
@@ -450,7 +452,15 @@ final Class<?> defineClassInternal(
 	}
 	if (className != null) {
 		String packageName = checkClassName(className);
-		checkPackageSigners(packageName, className, certs);
+		if ((protectionDomain == null) && allowNullProtectionDomain) {
+			/*
+			 * Skip checkPackageSigners(), in this condition, the caller of this method is 
+			 * java.lang.Access.defineClass() and invoked by trusted system code hence 
+			 * there is no need to check its ProtectionDomain and associated code source certificates.
+			 */
+		} else {
+			checkPackageSigners(packageName, className, certs);
+		}
 	}
 
 	if (offset < 0 || length < 0 || offset > classRep.length || length > classRep.length - offset) {
